@@ -1,5 +1,5 @@
-import os
 import git
+import os
 import typing
 
 
@@ -19,8 +19,12 @@ def git_unstaged_and_untracked_file_list(proj_dir: [str, git.Repo]) -> typing.Li
     file_list = list(file_set)
     file_list = file_list + repo.untracked_files
     filter_file_list = []
+    proj_dir = repo.git_dir
+    if proj_dir.endswith("/.git"):
+        last_index = proj_dir.rindex("/")
+        proj_dir = proj_dir[:last_index]
     for name in file_list:
-        abs_path = os.path.abspath(repo.git_dir, name)
+        abs_path = os.path.join(proj_dir, name)
         if os.path.exists(abs_path):
             filter_file_list.append(name)
     return filter_file_list
